********************************************************************************
*  REPLICATION OF DATA ANALYSIS FOR 										
*																			
*  RESTRICTIVE FERTILITY POLICY AND ELDERLY SUICIDES: EVIDENCE FROM CHINA 		 	
*
*                                   										
*  MANFEI LI AND UWE SUNDE                       
*  				                       										
*  Journal of Demographic Economics
*																			
*  May 2023															
*																			
********************************************************************************                                        

********************************************************************************
*  Note:   	this file contains the code for replicating the figures and tables
* 			in the paper.
*  See README file!															
********************************************************************************


**** Setting Paths

	global pathdata   	= "replication_data\"
	global pathout  	= "replication_output\"
	set scheme s1color

****FIGURES AND TABLES
**	create folders "figures" and "tables"

*==========Figure 1: Population Aging and Suicides Among the Elderly in China===
*==========Figure 1(a): Suicides by Age (2004-2017)==========
*============================================================
    clear
    import excel "$pathdata\generaltrend.xlsx", sheet("Sheet1") firstrow

preserve
	drop if age == 100
	bysort age: egen avegsr_f = mean(sr_f)
	bysort age: egen avegsr_m = mean(sr_m)
	bysort age: egen avegsr = mean(sr)
	
    line avegsr_f age, lcolor(black) lpattern(longdash) || ///
	line avegsr_m age, lcolor(black) lpattern(shortdash) || ///
	line avegsr age, lcolor(black) lpattern(solid) ||, ///
	ytitle("Suicide Rate per 100000 (Average)", margin(medsmall)) xtitle("Age", margin(medsmall)) xlabel(0(10)90) ///    
	legend(col(3)region(lpattern(blank)) label(1 "Female") label(2 "Male") label(3 "All"))

	graph export "$pathout\figures\Figure_1a.pdf", replace
restore

*==========Figure 1(b): Population Share Elderly==========
*============================================================
	clear
    import excel "$pathdata\population structure DSP.xlsx", sheet("Sheet1") firstrow
	save "$pathdata\population structure DSP.dta", replace
    
**	calculate share of elderly (age 60-89)
    bysort year: egen esample = total(sample)
    generate share_elderly = esample/total	
	drop esample
	
**	calculate share of elderly male (age 60-89)
    bysort year: egen esample_m = total(sample_m)
    generate share_elderly_m = esample_m/total_m
	drop esample_m
	
**	calculate share of elderly female (age 60-89)
    bysort year: egen esample_f = total(sample_f)
    generate share_elderly_f = esample_f/total_f
	drop esample_f

**  figure
preserve
    line share_elderly_f year if age==60, lcolor(black) lpattern(longdash) || ///
	line share_elderly_m year if age==60, lcolor(black) lpattern(shortdash) || ///
	line share_elderly year if age==60, lcolor(black) lpattern(solid) || if year<=2017, ///
	ytitle("Share of Population Aged 60 and Older", margin(medsmall)) xtitle("Year", margin(medsmall)) xlabel(2003(3)2018) ///    
	legend(col(3)region(lpattern(blank)) label(1 "Female") label(2 "Male") label(3 "All"))

	graph export "$pathout\figures\Figure_1b.pdf", replace
restore

*==========Figure 1(c): Percentage of Suicides by Elderly==========
*============================================================
	clear
    import excel "$pathdata\generaltrend.xlsx", sheet("Sheet1") firstrow
	drop if age == 100
	drop sr sr_m sr_f

** 	total number
    bysort year: egen totalsn = total(sn)
    bysort year: egen etotalsn = total(sn) if age>59 & age<90
    generate percentage = etotalsn/totalsn
    drop totalsn
	drop etotalsn
	
** 	total number male
    bysort year: egen totalsn_m = total(sn_m)
    bysort year: egen etotalsn_m = total(sn_m) if age>59 & age<90
    generate percentage_m = etotalsn_m/totalsn_m
    drop totalsn_m
	drop etotalsn_m
	
**  total number female
    bysort year: egen totalsn_f = total(sn_f)
    bysort year: egen etotalsn_f = total(sn_f) if age>59 & age<90
    generate percentage_f = etotalsn_f/totalsn_f
    drop totalsn_f
    drop etotalsn_f

**  figure
preserve
    line percentage_f year if age==60, lcolor(black) lpattern(longdash) || ///
	line percentage_m year if age==60, lcolor(black) lpattern(shortdash) || ///
	line percentage year if age==60, lcolor(black) lpattern(solid) || if year<=2017, ///
	ytitle("Percentage of Elderly Suicides", margin(medsmall)) xtitle("Year", margin(medsmall)) xlabel(2003(3)2018) ///    
	legend(col(3)region(lpattern(blank)) label(1 "Female") label(2 "Male") label(3 "All"))
	
	graph export "$pathout\figures\Figure_1c.pdf", replace
restore

*==========Figure 2: The Dynamics of Fertility and Fertility Policies in China==
*============================================================


	clear all
	use "$pathdata/unpopulation_tfr.dta"
	label variable TFR "Total Fertility Rate"
	label variable year "Year"
	line TFR year if year<=2020, lcolor(navy) ytitle("Total Fertility Rate", margin(medsmall)) xtitle("Year", margin(medsmall)) xline(1969, lpattern(_)) xline(1979, lpattern(.-)) text(7 1972 "LLF") text(7 1982 "OCP") xlabel(1950(10)2020) legend(region(lpattern(blank)))
	graph export "$pathout\figures\Figure_2.pdf", replace


*==========Figure 3: Average Exposure to LLF Policies Across Birth Cohorts======
*============================================================
**	prepare suicide data
	clear all
    import excel "$pathdata/suiciderate.xlsx", sheet("Sheet1") firstrow

    drop if age<15
    expand abs(5)
    egen unit = concat(year region urbanicity gender age)
    bysort unit: egen seq = seq()
    replace seq = seq - 1 
    replace age = age + seq
    drop unit seq 	
    gen cohort=year-age
    egen id = concat(region urbanicity cohort)
    destring sr, replace
    save "$pathdata\suiciderate.dta", replace
	
**	prepare policyexposure data
	clear
    import excel "$pathdata\policyexposure.xlsx", sheet("Sheet1") firstrow
	save "$pathdata\policyexposure.dta", replace
	keep if cohort >= 1930 & cohort <= 1968

*   generage age when exposing to the policy    
    gen exposeage = policy-cohort+1
	replace exposeage = 15 if exposeage < 15
	
*   generate variable avefpp (average family planing policy)
    forvalues x = 15/49 {
        replace fertility`x'=0 if `x'< exposeage 
    } 
	
    egen fpp= rowtotal(fertility15-fertility49)
	keep region province urbanicity weight cohort fpp	
	egen id = concat(region urbanicity cohort)	
	egen num = total(fpp * weight), by(id) 
    egen den = total(weight), by(id) 
    gen avefpp = num/den
	keep id avefpp
    duplicates drop
	
**  prepare data for regression: merge suiciderate data to policyexposure
    merge 1:m id using "$pathdata\suiciderate.dta"
    drop if avefpp==.
    drop if age < 49 
	keep region urbanicity cohort gender year age sr avefpp

    save "$pathdata\baseline_data.dta", replace

**	figure
preserve
	bysort cohort: egen avepe = mean(avefpp) if age>=60 
	line avepe cohort if age>=60, lcolor(black) ///
	ytitle("Policy Exposure", margin(medsmall)) xtitle("Cohort", margin(medsmall)) /// 
	xlabel(1930(5)1960) legend(region(lpattern(blank)))
	
	graph export "$pathout\figures\Figure_3.pdf", replace
restore

*==========Table 1: Summary Statistics==========
*============================================================
	clear 
	use "$pathdata\baseline_data.dta"
	
**	variable adjustment
	egen regionXcohort = concat(region cohort) 
    encode region, generate(nregion)
    gen urban = .
	replace urban = 1 if urbanicity == "U"
	replace urban = 0 if urbanicity == "R"
    gen time=year-2003
    gen male = .
	replace male = 1 if gender == "M"
	replace male = 0 if gender == "F"
	
    label variable sr "Suicide Rate"
	label variable avefpp "Policy Exposure"
	label variable male "Male"
	label variable time "Time trend"
	label variable age "Age"
	label variable nregion "Region"
	label variable urban "Urban"
	label variable year "Year"
	label variable cohort "Cohort trend"
	label drop nregion
	label define nregion 1 "Center" 2 "East" 3 "West"
	
	gen groupage = .
	replace groupage = 45 if age>=45 & age<50
	replace groupage = 50 if age>=50 & age<55
	replace groupage = 55 if age>=55 & age<60
	replace groupage = 60 if age>=60 & age<65
	replace groupage = 65 if age>=65 & age<70
	replace groupage = 70 if age>=70 & age<75
	replace groupage = 75 if age>=75 & age<80
	replace groupage = 80 if age>=80 & age<85
	replace groupage = 85 if age>=85 & age<90
	
	g regrur=.
	replace regrur = 1 if nregion==1 & urban==0
	replace regrur = 2 if nregion==1 & urban==1
	replace regrur = 3 if nregion==2 & urban==0
	replace regrur = 4 if nregion==2 & urban==1
	replace regrur = 5 if nregion==3 & urban==0
	replace regrur = 6 if nregion==3 & urban==1
	
**	table
preserve
	quiet reg sr c.avefpp i.male time ib70.groupage if age>=60, cluster (regionXcohort)
	label variable cohort "Birth Cohort"
	g time_year = time+2003
	label variable time_year "Observation Year"
	estpost summarize sr avefpp male time_year age cohort if e(sample), listwise 
	esttab using "$pathout\tables\Table_1.tex", cells("count mean sd min max") b(%9.2f)  se(%9.2f) label  noobs replace prehead("{\begin{tabular}{l*{5}{c}}\toprule & Observations & Mean & Standard Dev. & Minimum & Maximum \\ ")   mlabels(,none) collabels(,none) eqlabels(none)
	drop time_year

estimates clear
restore

*==========Table 2: Policy Exposure and Elderly Suicides: Baseline Results==========
*============================================================
preserve
	quiet reg sr c.avefpp i.male time ib70.groupage if age>=60, cluster (regionXcohort)
	estimates store model1 //model1 baseline model

	quiet reg sr c.avefpp i.male i.time ib70.groupage if age>=60, cluster (regionXcohort)
	estimates store model2 //model2 year dummies

	quiet reg sr c.avefpp i.male i.time ib70.groupage cohort if age>=60, cluster (regionXcohort)
	estimates store model3 //model3 cohort trend

	quiet reg sr c.avefpp i.male i.time ib70.groupage ib1950.cohort if age>=60, cluster (regionXcohort)
	estimates store model4 //model4 control dummies
	
	esttab model1 model2 model3 model4 using "$pathout\tables\Table_2.tex", indicate("Age Groups = *.groupage" "Year = *.time" "Cohort = *.cohort") drop(_cons)  prehead("{\begin{tabular}{l*{4}{c}}\toprule&\multicolumn{4}{c}{Dependent variable: Suicide Rate}\\[.1cm] \cmidrule(lr){2-5} ")  b(%9.4f) r2(%9.4f) se(%9.4f) label nobaselevels star(* 0.10 ** 0.05 *** 0.01)  booktabs nonotes replace compress 

estimates clear
restore

*==========Table 3: Heterogeneous Effects by Sex, Area, and Cohort==========
*============================================================
	gen younger = . 
	gen older = .
	replace younger = 1 if age < 60 
	replace younger = 0 if younger == .
	label variable younger "Younger"

preserve
	quiet reg sr c.avefpp##i.male i.time ib70.groupage ib1950.cohort if age>=60, cluster (regionXcohort) //model1 male complex
	estimates store model1

	quiet reg sr c.avefpp##i.urban i.male i.time ib70.groupage ib1950.cohort if age>=60, cluster (regionXcohort)
	estimates store model2 //model2 urban complex

	quiet reg sr c.avefpp##i.nregion i.male i.time ib70.groupage ib1950.cohort if age>=60, cluster (regionXcohort)
	estimates store model3 //model3 region complex

	quiet reg sr c.avefpp i.male i.time ib70.groupage ib1950.cohort , cluster (regionXcohort)
	estimates store model4 //model4 all cohorts

	quiet reg sr c.avefpp i.male i.time ib70.groupage ib1950.cohort if young==1, cluster (regionXcohort)
	estimates store model5 //model5 younger cohorts

	esttab model1 model2 model3 model4 model5 using "$pathout\tables\Table_3.tex", indicate("Age Groups = *.groupage" "Year = *.time" "Cohort = *.cohort") drop(_cons)  prehead("{\begin{tabular}{l*{5}{c}}\toprule&\multicolumn{5}{c}{Dependent variable: Suicide Rate}\\[.1cm] \cmidrule(lr){2-6} ")  b(%9.3f) r2(%9.3f) se(%9.3f) label nobaselevels star(* 0.10 ** 0.05 *** 0.01)  booktabs nonotes replace compress 

estimates clear
restore

*==========Table 4: Heterogeneous Effects by Region and Urban/Rural Area==========
*============================================================
	forvalues i=1/6 {
		quiet reg sr c.avefpp i.male i.time ib70.groupage ib1950.cohort if age>=60 & regrur==`i', cluster (regionXcohort)
		estpost summarize sr avefpp if e(sample)
	}

preserve
/**	normal regression
	forvalues i=1/6 {
		quiet reg sr c.avefpp i.male i.time ib70.groupage ib1950.cohort if age>=60 & regrur==`i', cluster (regionXcohort)
		estimates store model`i'
	}
	
	esttab model1 model2 model3 model4 model5 model6 using "$pathout\tables\Table_4slim.tex", indicate("Male = *.male" "Age Groups = *.groupage" "Year = *.time" "Cohort = *.cohort" ) drop(_cons)  prehead("{\begin{tabular}{l*{6}{c}}\toprule&\multicolumn{6}{c}{Dependent variable: Suicide Rate}\\ Sample: &Center/Rural & Center/Urban & East/Rural & East/Urban & West/Rural & West/Urban \\[.1cm] \cmidrule(lr){2-7} ") prefoot("\midrule Mean Suicide Rate & 56.1 & 22.5 & 29.3 & 14.0 & 25.4 & 18.7 \\ Mean Policy Exp. & 2.70 & 1.42 & 2.28 & 0.88 & 2.83 & 1.36 \\ ")    b(%9.3f) r2(%9.3f) se(%9.3f) label nobaselevels star(* 0.10 ** 0.05 *** 0.01)  booktabs nonotes fragment replace compress  
*/

	
**	standardized version
	g avefpp_std = .
	forvalues i=1/6 {
		quiet reg sr c.avefpp i.male i.time ib70.groupage ib1950.cohort if age>=60 & regrur==`i', cluster (regionXcohort)
		egen sr_std`i' = std(sr) if e(sample)
		egen avefpp_std`i' = std(avefpp) if e(sample)
		replace avefpp_std = avefpp_std`i'
		label variable avefpp_std "beta-coeff."
		quiet reg sr_std`i' c.avefpp_std i.male i.time ib70.groupage ib1950.cohort if age>=60 & regrur==`i', cluster (regionXcohort)
		estimates store models`i'
	}
	
	esttab models1 models2 models3 models4 models5 models6 using "$pathout\tables\Table_4.tex", drop(_cons *.male *.groupage *.time *.cohort)  postfoot("\bottomrule\end{tabular}}") b(%9.3f) se(%9.3f)  label nobaselevels star(* 0.10 ** 0.05 *** 0.01)  booktabs nonotes noobs nomtitle nonumbers fragment append compress 

	drop sr_std* avefpp_std avefpp_std* 

estimates clear
restore

*==========Figure 4: Placebo: Random Implementation of Policy (Time)==========
*============================================================
	clear
    use "$pathdata\policyexposure.dta"
	
**  generate province dataset
    keep province 
	duplicates drop
	save "$pathdata\placebo_output_data\province.dta", replace

**  create placebo treatment mappings	
	forv i=2(1)1001 {
	    clear
	    use "$pathdata\placebo_output_data\province.dta"

		gen provincerandomid=uniform()
		sort provincerandomid

		gen policy=.
		replace policy=1969 in 1
		replace policy=1970 in 2
		replace policy=1971 in 3/9
		replace policy=1972 in 10/21
		replace policy=1973 in 22/25
		replace policy=1974 in 26
		replace policy=1975 in 27/28

		drop provincerandomid
		sort province
	
		save "$pathdata\placebo_output_data\province`i'.dta", replace	
	}

** regressions
    tempname p
	postfile `p' float rep beta sebeta t using "$pathdata\placebo_output_data\results1_random_policyyear.dta", replace
	
*  baseline model
    clear 
	use "$pathdata\baseline_data.dta"

	egen regionXcohort = concat(region cohort) 
    encode gender, generate(ngender)      
    gen time=year-2003	
	gen groupage = .
	replace groupage = 45 if age>=45 & age<50
	replace groupage = 50 if age>=50 & age<55
	replace groupage = 55 if age>=55 & age<60
	replace groupage = 60 if age>=60 & age<65
	replace groupage = 65 if age>=65 & age<70
	replace groupage = 70 if age>=70 & age<75
	replace groupage = 75 if age>=75 & age<80
	replace groupage = 80 if age>=80 & age<85
	replace groupage = 85 if age>=85 & age<90
	    
	quietly{
	reg sr c.avefpp i.ngender time ib70.groupage if age>=60, cluster (regionXcohort)
	}
    
	local beta =_b[avefpp]
	local se =_se[avefpp]
	post `p' (1) (`beta') (`se') (`=`beta'/`se'')

*   random draw results
	forv i=2(1)1001 {	
	    clear
        use "$pathdata\policyexposure.dta"
   
        drop policy
		merge m:1 province using "$pathdata\placebo_output_data\province`i'.dta"		
		keep if cohort >= 1930 & cohort <= 1957
        gen exposeage = policy-cohort+1
		order region province urbanicity weight cohort policy exposeage

        forvalues x=15/49 {
            replace fertility`x'=0 if `x'< exposeage 
        } 

        egen fpp= rowtotal(fertility15-fertility49)
	    keep region province urbanicity weight cohort fpp
	    sort region province urbanicity cohort
        order region province urbanicity weight cohort fpp	
	    egen id = concat(region urbanicity cohort)	
	    egen num = total(fpp * weight), by(id) 
        egen den = total(weight), by(id) 
        gen avefpp = num/den
	    keep id avefpp
	    sort id
        duplicates drop
		
		merge 1:m id using "$pathdata\suiciderate.dta"		
        sort region urbanicity cohort gender year age
	    order region urbanicity cohort id gender year age sr avefpp
        drop if avefpp==.
        drop if age<60
	    keep region urbanicity cohort gender year age sr avefpp			
		egen regionXcohort = concat(region cohort) 
        encode gender, generate(ngender)     
        gen time=year-2003	
		gen groupage = .
	    replace groupage = 45 if age>=45 & age<50
		replace groupage = 50 if age>=50 & age<55
		replace groupage = 55 if age>=55 & age<60
		replace groupage = 60 if age>=60 & age<65
		replace groupage = 65 if age>=65 & age<70
		replace groupage = 70 if age>=70 & age<75
		replace groupage = 75 if age>=75 & age<80
		replace groupage = 80 if age>=80 & age<85
		replace groupage = 85 if age>=85 & age<90
	    
		quietly{
		reg sr c.avefpp i.ngender time ib70.groupage if age>=60, cluster (regionXcohort)
		}
    
	    local beta =_b[avefpp]
	    local se =_se[avefpp]
	    post `p' (`i') (`beta') (`se') (`=`beta'/`se'')				
		erase "$pathdata\placebo_output_data\province`i'.dta"
	}
	
	postclose `p'	
	erase "$pathdata\placebo_output_data\province.dta"
	
**	figure	
	clear
    use "$pathdata\placebo_output_data\results1_random_policyyear.dta"

*	beta
preserve
	summ beta in 1
	local beta = r(mean)
	histogram beta, scheme(s1color) xline(`beta', extend) xtitle("Coefficients (Policy Exposure)")
	
	graph export "$pathout\figures\Figure_4a.pdf", replace
restore	 

*	t statistics
preserve
	summ t in 1
	local t = r(mean)
	count if abs(t)>5.2 & rep != 1
	histogram t, scheme(s1color) xline(`t', extend) xtitle("t-stat (Policy Exposure)") /*text(2 7.5 "p=`=`r(N)'/1000'", place(e))*/ saving(1, replace) 
	
	graph export "$pathout\figures\Figure_4b.pdf", replace
restore

*==========Figure 5: Placebo: Random Implementation of Policy (Space and Cohorts)==========
*============================================================
**  1. cohort
    clear
    use "$pathdata\policyexposure.dta"

*   1. a) generate cohort fertility dataset
    keep if cohort >= 1930 & cohort <= 1957
    gen exposeage = policy-cohort+1
    order region province urbanicity weight cohort policy exposeage

    forvalues x=15/49 {
        replace fertility`x'=0 if `x'< exposeage 
    } 

    egen fpp= rowtotal(fertility15-fertility49)	
	keep province urbanicity cohort fpp
	sort province urbanicity cohort fpp
    order province urbanicity cohort fpp

	save "$pathdata\placebo_output_data\cohort.dta"
	
*  1. b) create placebo treatment mappings (across cohorts within space)
	forv i=2(1)1001 {
	    clear
	    use "$pathdata\placebo_output_data\cohort.dta"
		
		egen space = group(province urbanicity)
		sort space
		bysort space: gen cohortrandomid=uniform()
		sort space cohortrandomid		
		bysort space: egen ncohort = seq()
		sort space cohort 
		replace cohort = ncohort +1929 
		keep space cohort fpp
			
		save "$pathdata\placebo_output_data\cohort`i'.dta", replace	
	}

**  2. space
	clear
    use "$pathdata\policyexposure.dta"

*   2. a) generate provinceXurbanicity (space unit) dataset
    keep region province urbanicity weight policy 
	duplicates drop
	save "$pathdata\placebo_output_data\space.dta"
	
*   2. b) create placebo treatment mappings	(across space)
	forv i=2(1)1001 {
	  clear
	    use "$pathdata\placebo_output_data\space.dta"

		gen spacerandomid=uniform()
		sort spacerandomid
		egen space = seq()
		drop spacerandomid
		sort space
	
		save "$pathdata\placebo_output_data\space`i'.dta", replace
	} 
 
**	regressions
    tempname p
	postfile `p' float rep beta sebeta t using "$pathdata\placebo_output_data\results1_random_fertility_both.dta", replace
	
*   baseline model
    clear 
	use "$pathdata\baseline_data.dta"

	egen regionXcohort = concat(region cohort) 
    encode gender, generate(ngender)      
    gen time=year-2003	
	gen groupage = .
	replace groupage = 45 if age>=45 & age<50
	replace groupage = 50 if age>=50 & age<55
	replace groupage = 55 if age>=55 & age<60
	replace groupage = 60 if age>=60 & age<65
	replace groupage = 65 if age>=65 & age<70
	replace groupage = 70 if age>=70 & age<75
	replace groupage = 75 if age>=75 & age<80
	replace groupage = 80 if age>=80 & age<85
	replace groupage = 85 if age>=85 & age<90
	    
	quietly{
	reg sr c.avefpp i.ngender time ib70.groupage if age>=60, cluster (regionXcohort)
	}
    
	local beta =_b[avefpp]
	local se =_se[avefpp]
	post `p' (1) (`beta') (`se') (`=`beta'/`se'')	
	
*  random draw results   	
	forv i=2(1)1001 {
        clear
	    use "$pathdata\placebo_output_data\cohort`i'.dta"

        merge m:1 space using "$pathdata\placebo_output_data\space`i'.dta"
	    keep region province urbanicity weight cohort fpp
        egen id = concat(region urbanicity cohort)	
	    egen num = total(fpp * weight), by(id) 
        egen den = total(weight), by(id) 
        gen avefpp = num/den
	    keep id avefpp
	    sort id
        duplicates drop
			
		merge 1:m id using "$pathdata\suiciderate.dta"
        sort region urbanicity cohort gender year age
	    order region urbanicity cohort id gender year age sr avefpp
        drop if avefpp==.
        drop if age<60
	    keep region urbanicity cohort gender year age sr avefpp      		
		egen regionXcohort = concat(region cohort) 
        encode gender, generate(ngender)      
        gen time=year-2003	    
		gen groupage = .
	    replace groupage = 45 if age>=45 & age<50
		replace groupage = 50 if age>=50 & age<55
		replace groupage = 55 if age>=55 & age<60
		replace groupage = 60 if age>=60 & age<65
		replace groupage = 65 if age>=65 & age<70
		replace groupage = 70 if age>=70 & age<75
		replace groupage = 75 if age>=75 & age<80
		replace groupage = 80 if age>=80 & age<85
		replace groupage = 85 if age>=85 & age<90
	    
		quietly{
		reg sr c.avefpp i.ngender time ib70.groupage if age>=60, cluster (regionXcohort)
		}
    
	    local beta =_b[avefpp]
	    local se =_se[avefpp]
	    post `p' (`i') (`beta') (`se') (`=`beta'/`se'')				
		erase "$pathdata\placebo_output_data\cohort`i'.dta"
		erase "$pathdata\placebo_output_data\space`i'.dta"
	}
	
	postclose `p'
	erase "$pathdata\placebo_output_data\cohort.dta"
	erase "$pathdata\placebo_output_data\space.dta"

**	figures
	clear
    use "$pathdata\placebo_output_data\results1_random_fertility_both.dta"

*   beta
preserve
	summ beta in 1
	local beta = r(mean)
	histogram beta, scheme(s1color) xline(`beta', extend) xtitle("Coefficients (Policy Exposure)")
	
	graph export "$pathout\figures\Figure_5a.pdf", replace
restore	 

*	t statistics	
preserve
	summ t in 1
	local t = r(mean)
	count if abs(t)>5.2 & rep != 1
	histogram t, scheme(s1color) xline(`t', extend) xtitle("t-stat (Policy Exposure)") /*text(0.2 -6.5 "p=`=`r(N)'/1000'", place(e))*/ saving(1, replace) //xscale(range(6 8)) 
	
	graph export "$pathout\figures\Figure_5b.pdf", replace
restore

*==========Figure 6: Placebo: Random Implementation of Policy (Space, Cohort, and Time)==========
*============================================================
*** three randomized dimensions
**  1. randomize policy year
    clear
    use "$pathdata\policyexposure.dta"
	
*   1. a) generate province dataset
    keep province 
	duplicates drop
	save "$pathdata\placebo_output_data\province.dta", replace

*   1. b) create placebo treatment mappings
	forv i=2(1)1001 {
	    clear
	    use "$pathdata\placebo_output_data\province.dta"

		gen provincerandomid=uniform()
		sort provincerandomid
		gen policy=.
		replace policy=1969 in 1
		replace policy=1970 in 2
		replace policy=1971 in 3/9
		replace policy=1972 in 10/21
		replace policy=1973 in 22/25
		replace policy=1974 in 26
		replace policy=1975 in 27/28

		drop provincerandomid
		sort province
		
		save "$pathdata\placebo_output_data\province`i'.dta", replace	
	}	
	
**  2. merge randomized policy year to policy exposure data
	forv i=2(1)1001 {
        clear 
		use "$pathdata\policyexposure.dta"
        drop policy
		merge m:1 province using "$pathdata\placebo_output_data\province`i'.dta"
		save "$pathdata\placebo_output_data\random`i'.dta"
		erase "$pathdata\placebo_output_data\province`i'.dta"
    }
	
**  3. randomize the rest (randomize the exposure across all observations)
	forv i=2(1)1001 {
	    clear
        use "$pathdata\placebo_output_data\random`i'.dta"
		
		keep if cohort >= 1930 & cohort <= 1957
        gen exposeage = policy-cohort+1
        order region province urbanicity weight cohort policy exposeage

        forvalues x=15/49 {
            replace fertility`x'=0 if `x'< exposeage 
        } 

        egen fpp= rowtotal(fertility15-fertility49)	    
		keep region province urbanicity cohort weight fpp
		sort region province urbanicity cohort 
		order region province urbanicity cohort 	
		egen id = group(region province urbanicity cohort)
		save "$pathdata\placebo_output_data\random`i'.dta", replace
				
		drop region province urbanicity cohort weight id 		
		gen randomid=uniform()
		sort randomid
		egen id = seq()
		drop randomid		
		save "$pathdata\placebo_output_data\fpp`i'.dta"
		
		clear
        use "$pathdata\placebo_output_data\random`i'.dta"
		drop fpp 
		merge 1:1 id using "$pathdata\placebo_output_data\fpp`i'.dta"
		drop id
		save "$pathdata\placebo_output_data\random`i'.dta", replace
		erase "$pathdata\placebo_output_data\fpp`i'.dta"		
	}	
		
**	regressions
    tempname p
	postfile `p' float rep beta sebeta t using "$pathdata\placebo_output_data\results1_random_all.dta", replace
		
*   baseline model
    clear 
	use "$pathdata\baseline_data.dta"

	egen regionXcohort = concat(region cohort) 
    encode gender, generate(ngender)
       
    gen time=year-2003
	
	gen groupage = .
	replace groupage = 45 if age>=45 & age<50
	replace groupage = 50 if age>=50 & age<55
	replace groupage = 55 if age>=55 & age<60
	replace groupage = 60 if age>=60 & age<65
	replace groupage = 65 if age>=65 & age<70
	replace groupage = 70 if age>=70 & age<75
	replace groupage = 75 if age>=75 & age<80
	replace groupage = 80 if age>=80 & age<85
	replace groupage = 85 if age>=85 & age<90
	    
	quietly{
	reg sr c.avefpp i.ngender time ib70.groupage if age>=60, cluster (regionXcohort)
	}
    
	local beta =_b[avefpp]
	local se =_se[avefpp]
	post `p' (1) (`beta') (`se') (`=`beta'/`se'')	
	  
*   random draw results   	 
	forv i=2(1)1001 {

        clear
	    use "$pathdata\placebo_output_data\random`i'.dta"
			
        egen id = concat(region urbanicity cohort)
	    egen num = total(fpp * weight), by(id) 
        egen den = total(weight), by(id) 
        gen avefpp = num/den
	    keep id avefpp
	    sort id
        duplicates drop
		
		merge 1:m id using "$pathdata\suiciderate.dta"
		sort region urbanicity cohort gender year age
	    order region urbanicity cohort id gender year age sr avefpp
        drop if avefpp==.
        drop if age<60
	    keep region urbanicity cohort gender year age sr avefpp			
		egen regionXcohort = concat(region cohort) 
        encode gender, generate(ngender)     
        gen time=year-2003	    
		gen groupage = .
	    replace groupage = 45 if age>=45 & age<50
		replace groupage = 50 if age>=50 & age<55
		replace groupage = 55 if age>=55 & age<60
		replace groupage = 60 if age>=60 & age<65
		replace groupage = 65 if age>=65 & age<70
		replace groupage = 70 if age>=70 & age<75
		replace groupage = 75 if age>=75 & age<80
		replace groupage = 80 if age>=80 & age<85
		replace groupage = 85 if age>=85 & age<90
	    
		quietly{
		reg sr c.avefpp i.ngender time ib70.groupage if age>=60, cluster (regionXcohort)
		}
    
	    local beta =_b[avefpp]
	    local se =_se[avefpp]
	    post `p' (`i') (`beta') (`se') (`=`beta'/`se'')				
		erase "$pathdata\placebo_output_data\random`i'.dta"	
	}

    postclose `p'   
	erase "$pathdata\placebo_output_data\province.dta"

**	figure
	clear
    use "$pathdata\placebo_output_data\results1_random_all.dta"

*   beta
preserve
	summ beta in 1
	local beta = r(mean)
	histogram beta, scheme(s1color) xline(`beta', extend) xtitle("Coefficients (Policy Exposure)")
	
	graph export "$pathout\figures\Figure_6a.pdf", replace
restore	 

*	t statistics	
preserve
	summ t in 1
	local t = r(mean)
	count if abs(t)>5.2 & rep != 1
	histogram t, scheme(s1color) xline(`t', extend) xtitle("t-stat (Policy Exposure)") /*text(0.4 -5 "p=`=`r(N)'/1000'", place(e))*/ saving(1, replace) //xscale(range(6 8)) 
	
	graph export "$pathout\figures\Figure_6b.pdf", replace
restore
clear